import { Rectangle } from "../model/interface/Rectangle";
import { Position } from "../model/msic/graphics";
import { BaseApi } from "./BaseApi";
interface IBrowserWindowApi {
    setIgnoreMouseEvent(ignore: boolean): Promise<void>;
    show(): Promise<void>;
    hide(): Promise<void>;
    showInactive(): Promise<void>;
    center(): Promise<void>;
    startDraggingWindow(): Promise<void>;
    stopDraggingWindow(): Promise<void>;
    setAlwaysOnTop(alwaysOnTop: boolean): Promise<void>;
    isAlwaysOnTop(): Promise<boolean>;
    openUrl(url: string, option?: OpenUrlOptions): Promise<void>;
    moveTop(): Promise<void>;
    openDevTools(): Promise<void>;
    setPosition(x: number, y: number, animation: boolean): Promise<void>;
    getPosition(): Promise<Position>;
    blur(): Promise<void>;
    focus(): Promise<void>;
    setResizable(resizable: boolean): Promise<void>;
    getBounds(): Promise<Rectangle>;
    setBounds(bounds: Partial<Rectangle>, animate: boolean): Promise<void>;
    alignToScreen(align: AlignPosition): Promise<void>;
    existsByUrl(url: string): Promise<boolean>;
}
type BrowserWindowApiMethods = keyof IBrowserWindowApi;
type AlignPosition = 'top-left' | 'top-center' | 'top-right' | 'bottom-left' | 'bottom-center' | 'bottom-right';
interface OpenUrlOptions {
    partition?: string;
}
declare enum BrowserWindowApiEvent {
    BLUR = "event::cn.widgetjs.core.browser-window.blur",
    FOCUS = "event::cn.widgetjs.core.browser-window.focus"
}
export declare class BrowserWindowApiImpl extends BaseApi<BrowserWindowApiMethods> implements IBrowserWindowApi {
    getChannel(): string;
    setIgnoreMouseEvent(ignore: boolean): Promise<void>;
    show(): Promise<void>;
    showInactive(): Promise<void>;
    hide(): Promise<void>;
    center(): Promise<void>;
    setAlwaysOnTop(alwaysOnTop: boolean): Promise<void>;
    isAlwaysOnTop(): Promise<boolean>;
    openUrl(url: string, option?: OpenUrlOptions): Promise<void>;
    moveTop(): Promise<void>;
    openDevTools(): Promise<void>;
    /**
     * 设置窗口位置
     * @param x
     * @param y
     * @param animation 动画只在mac系统有效
     */
    setPosition(x: number, y: number, animation: boolean): Promise<void>;
    getPosition(): Promise<Position>;
    blur(): Promise<any>;
    focus(): Promise<any>;
    /**
     * 设置窗口是否可以拉伸
     * @param resizable
     */
    setResizable(resizable: boolean): Promise<any>;
    getBounds(): Promise<Rectangle>;
    setBounds(bounds: Partial<Rectangle>, animate?: boolean): Promise<void>;
    alignToScreen(align: AlignPosition): Promise<any>;
    startDraggingWindow(): Promise<any>;
    stopDraggingWindow(): Promise<any>;
    /**
     * 通过url检测窗口是否存在
     * @param url
     */
    existsByUrl(url: string): Promise<boolean>;
}
declare const BrowserWindowApi: BrowserWindowApiImpl;
export { BrowserWindowApi, BrowserWindowApiMethods, OpenUrlOptions, BrowserWindowApiEvent, AlignPosition };
